@@ -47,7 +47,10 @@ class Geo_common:
             self.series[k] = v
         # samples: 样本信息 ,  dict = {sample:{group:x, IP/Input:x, raw_file_r1:x, raw_file_r2:x}}
         self.samples = collections.defaultdict(dict)
-        data = ParserXLS.fetch_row(excel, main_name, "SAMPLES")        # sample name 必须在第一列
+        which_sheet = main_name
+        if project_name in ["WES","WGS"]:         # 这些项目的样本信息在自己的项目页面
+            which_sheet = project_name
+        data = ParserXLS.fetch_row(excel, which_sheet, "SAMPLES")        # sample name 必须在第一列
         for line in data[1:]:
             for head in data[0][1:]:
                 tmp = line[data[0].index(head)]
